@@ -277,7 +277,7 @@ namespace lime {
 		std::vector<std::shared_ptr<DR<Curve>>> DRSessions{};
 		// load in DRSessions all the session found in cache for this peer device, except the one with id db_sessionIdInCache(is ignored if 0) as we already tried it
 		get_DRSessions(senderDeviceId, db_sessionIdInCache, DRSessions);
-		LIME_LOGD<<"decrypt from "<<senderDeviceId<<" to "<<recipientUserId<<" : found "<<DRSessions.size()<<" sessions in DB";
+		LIME_LOGI<<"decrypt from "<<senderDeviceId<<" to "<<recipientUserId<<" : found "<<DRSessions.size()<<" sessions in DB";
 		auto usedDRSession = decryptMessage<Curve>(senderDeviceId, m_selfDeviceId, recipientUserId, DRSessions, DRmessage, cipherMessage, plainMessage);
 		if (usedDRSession != nullptr) { // we manage to decrypt with a session
 			m_DR_sessions_cache[senderDeviceId] = std::move(usedDRSession); // store it in cache
@@ -287,6 +287,7 @@ namespace lime {
 		// No luck yet, is this message holds a X3DH header - if no we must give up
 		std::vector<uint8_t> X3DH_initMessage{};
 		if (!double_ratchet_protocol::parseMessage_get_X3DHinit<Curve>(DRmessage, X3DH_initMessage)) {
+			LIME_LOGE<<"Fail to decrypt: No DR session found and no X3DH init message";
 			return lime::PeerDeviceStatus::fail;
 		}
 
@@ -305,6 +306,7 @@ namespace lime {
 			m_DR_sessions_cache[senderDeviceId] = std::move(DRSessions.front());
 			return senderDeviceStatus;
 		}
+		LIME_LOGE<<"Fail to decrypt: Newly created DR session failed to decrypt the message";
 		return lime::PeerDeviceStatus::fail;
 	}
 
@@ -405,37 +407,33 @@ namespace lime {
 		/* open DB */
 		auto localStorage = std::unique_ptr<lime::Db>(new lime::Db(dbFilename, db_mutex)); // create as unique ptr, ownership is then passed to the Lime structure when instanciated
 
-		try {
-			//instanciate the correct Lime object
-			switch (curve) {
-				case lime::CurveId::c25519 :
+		//instanciate the correct Lime object
+		switch (curve) {
+			case lime::CurveId::c25519 :
 #ifdef EC25519_ENABLED
-				{
-					/* constructor will insert user in Db, if already present, raise an exception*/
-					auto lime_ptr = std::make_shared<Lime<C255>>(std::move(localStorage), deviceId, url, X3DH_post_data);
-					lime_ptr->publish_user(callback, OPkInitialBatchSize);
-					return lime_ptr;
-				}
-#endif
-				break;
-
-				case lime::CurveId::c448 :
-#ifdef EC448_ENABLED
-				{
-					auto lime_ptr = std::make_shared<Lime<C448>>(std::move(localStorage), deviceId, url, X3DH_post_data);
-					lime_ptr->publish_user(callback, OPkInitialBatchSize);
-					return lime_ptr;
-				}
-#endif
-				break;
-
-				case lime::CurveId::unset :
-				default: // asking for an unsupported type
-					throw BCTBX_EXCEPTION << "Cannot create lime user "<<deviceId;//<<". Unsupported curve (id <<"static_cast<uint8_t>(curve)") requested";
-				break;
+			{
+				/* constructor will insert user in Db, if already present, raise an exception*/
+				auto lime_ptr = std::make_shared<Lime<C255>>(std::move(localStorage), deviceId, url, X3DH_post_data);
+				lime_ptr->publish_user(callback, OPkInitialBatchSize);
+				return lime_ptr;
 			}
-		} catch (BctbxException &) {
-			throw; // just forward the exceptions raised by constructor
+#endif
+			break;
+
+			case lime::CurveId::c448 :
+#ifdef EC448_ENABLED
+			{
+				auto lime_ptr = std::make_shared<Lime<C448>>(std::move(localStorage), deviceId, url, X3DH_post_data);
+				lime_ptr->publish_user(callback, OPkInitialBatchSize);
+				return lime_ptr;
+			}
+#endif
+			break;
+
+			case lime::CurveId::unset :
+			default: // asking for an unsupported type
+				throw BCTBX_EXCEPTION << "Cannot create lime user "<<deviceId;//<<". Unsupported curve (id <<"static_cast<uint8_t>(curve)") requested";
+				break;
 		}
 		return nullptr;
 	};
@@ -478,28 +476,23 @@ namespace lime {
 #endif
 
 
-		try {
-			switch (curve) {
-				case lime::CurveId::c25519 :
+		switch (curve) {
+			case lime::CurveId::c25519 :
 #ifdef EC25519_ENABLED
-					return std::make_shared<Lime<C255>>(std::move(localStorage), deviceId, x3dh_server_url, X3DH_post_data, Uid);
+				return std::make_shared<Lime<C255>>(std::move(localStorage), deviceId, x3dh_server_url, X3DH_post_data, Uid);
 #endif
-				break;
+			break;
 
-				case lime::CurveId::c448 :
+			case lime::CurveId::c448 :
 #ifdef EC448_ENABLED
-
-					return std::make_shared<Lime<C448>>(std::move(localStorage), deviceId, x3dh_server_url, X3DH_post_data, Uid);
+				return std::make_shared<Lime<C448>>(std::move(localStorage), deviceId, x3dh_server_url, X3DH_post_data, Uid);
 #endif
-				break;
+			break;
 
-				case lime::CurveId::unset :
-				default: // asking for an unsupported type
-					throw BCTBX_EXCEPTION << "Cannot create load user "<<deviceId;
-				break;
-			}
-		} catch (BctbxException &) {
-			throw;
+			case lime::CurveId::unset :
+			default: // asking for an unsupported type
+				throw BCTBX_EXCEPTION << "Cannot create load user "<<deviceId;
+			break;
 		}
 		return nullptr;
 	};
